# NearBeach
NearBeach is in currently alpha development. If you find any issues, please do not hesitate to submit an issue. Alternatively you can submit through https://nearbeach.atlassian.net/servicedesk/customer/portal/1 (login not required)

## What is NearBeach?
NearBeach is a project and task management tool (PATMT) with a basic customer relationship management tool to help you manage your projects and task. The phillosophy of NearBeach is to be easy to install and use, be open sourced, be flexible, and aimed at small/personal organisation to large enterprises. Each new module brought to NearBeach expands it's capability tenfold and brings it closer to a competing product.

## Features
NearBeach's main focus is to create both projects and task. Each task can then be assigned to as many projects required (sometimes multiple projects will need to have the same task completed). Each project and task can also be assigned to multiple users to complete.
![NearBeach - Project Information](https://github.com/robotichead/Store_Github_Pictures/blob/master/NearBeach%20-%20project%20information.png?raw=true)

However projects and task are but a small feature to a PATMT system. You will need to store user requirement and be able to assign those requirement items to projects/task for completion. You will need to track these requirement to make sure they are completed. NearBeach has recently implemented a requirement module to help you store all your customer's requirement
![NearBeach - Requirements](https://github.com/robotichead/Store_Github_Pictures/blob/master/NearBeach%20-%20Requirements.png?raw=true)

What if you have an opportunity? You do not have the user's full requirement yet, but there could easily be a sale involved. NearBeach has also implemented the opportunity module, to help you store each potential opportunity that comes through the pipeline.
![NearBeach - Opportunity](https://github.com/robotichead/Store_Github_Pictures/blob/master/NearBeach%20-%20Opportunity?raw=true)


Finally, you might need to send a quote to your customer. As a new feature, the Quotes module has been implemented into NearBeach.
![NearBeach - Quotes](https://github.com/robotichead/Store_Github_Pictures/blob/master/NearBeach%20-%20Quote3.png?raw=true)
![NearBeach - Quotes](https://github.com/robotichead/Store_Github_Pictures/blob/master/NearBeach%20-%20Quote1.png?raw=true)

These are not the only features in NearBeach, but some which you may start using strait away. Feel free to download and install and start using NearBeach right away.

## Software References (thank you)

NearBeach will not be where it currently is without the help of other open sourced projects. Below are the references to all the different tools that are utilised within NearBeach. NearBeach would like to thank these projects as they have help construct a better and more stable product. Please consider visiting and donating.

### jQuery
Creator(s): John Resig

Github: https://github.com/jquery/jquery

Link: jquery.com

License: MIT

Note: jQuery help shorten a lot of the javascript code within NearBeach. There are also a few widgets that rely on this technology (i.e. Chosen-js).



### jQuery File Upload
Creator(s): Sebastian Tschan

Github: https://github.com/blueimp/jQuery-File-Upload

Link: https://blueimp.github.io/jQuery-File-Upload/

License : MIT

Note: jQuery File Upload is used when there is a file to be uploaded through the AJAX method.



### jQuery Plugin Date and Time Picker
Creator(s): Valeriy Chupurnov

Github: https://github.com/xdan/datetimepicker

License: MIT

Note: This plugin is a widget used to help improve picking dates and time.



### TinyMCE
Creator(s):  Tiny Technologies Inc.

Github: https://github.com/tinymce/tinymce

License: GNU Lesser General Public License v2.1

Note: TinyMCE is used for rich text within NearBeach


### Geolocation - Python
Creator(s): Sławomir Kabik

Github: https://github.com/slawek87/geolocation-python

License: BSD 3-Clause

Note: Geolocation-Python is used to contact both Google Maps and Mapbox's API.



### Weasy Print
Creator(s): Kozea 

Website: https://weasyprint.org/

Github: https://github.com/Kozea/WeasyPrint

License: BSD 3-Clause

Note: Weasy print is used to render PDF's in NearBeach

### Undraw.io <- images 

### D3.js (Data-Driven Documents)
Creator(s): Mike Bostock, Jason Davies, Jeffrey Heer, Vadim Ogievetsky

Website: https://d3js.org/

Github: https://github.com/d3/d3

License: BSD 3-Clause

Note: D3 is used for producing graphical representatives of data for NearBeach




### Gantt-Chart
Creator(s): Dimitry Kudryavtsev

Github: https://github.com/dk8996/Gantt-Chart

License: Apache-2.0

Note: Gantt-Chart will be used for NearBeach's timeline feature.


### Bootstrap
Creator(s): Mark Otto, Jacob Thornton

Github: https://github.com/twbs/bootstrap

License: MIT

Note: NearBeach's CSS is currently being migrated to Bootstrap. For easy development.



### Feather Icons
Creator(s): Carmelo Pullara, Cole Bemis, Oliver Dumoulin

Github: https://github.com/feathericons/feather

License: MIT

Note: Feather icons are icons being utilised by NearBeach



### Django-select2
Creator(s): AppleGrew

Github: https://github.com/applegrew/django-select2

License: MIT

Note: NearBeach uses Djanogo-select2 to improve it's User Experience dealing with select statements.


### Select2
Creator(s): Select2

Github: https://github.com/select2/select2

License: MIT

Note: Django-select2 is built a top this product